@@ -10,7 +10,7 @@
 # ABSTRACT: Dump the configuration of an application
 
 package App::Cme::Command::dump ;
-$App::Cme::Command::dump::VERSION = '1.002';
+$App::Cme::Command::dump::VERSION = '1.003';
 use strict;
 use warnings;
 use 5.10.1;
@@ -56,7 +56,7 @@ sub execute {
 
     my ($model, $inst, $root) = $self->init_cme($opt,$args);
 
-    my $dump_string = $root->dump_tree( mode => YYY $opt->{dumptype} );
+    my $dump_string = $root->dump_tree( mode => $opt->{dumptype} );
     print $dump_string ;
 
 }
@@ -75,7 +75,7 @@ App::Cme::Command::dump - Dump the configuration of an application
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 SYNOPSIS
 
